"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SoftDeletableHandlerSubscriber = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@mikro-orm/core");
const soft_deletable_decorator_1 = require("./soft-deletable.decorator");
const soft_deletable_symbol_1 = require("./soft-deletable.symbol");
/**
 * Intercept deletions of soft-deletable entities and perform updates instead.
 *
 * @see SoftDeletable
 * @see https://github.com/mikro-orm/mikro-orm/issues/1492#issuecomment-785394397
 */
let SoftDeletableHandlerSubscriber = class SoftDeletableHandlerSubscriber {
    async onFlush({ uow }) {
        const deletionChangeSets = uow
            .getChangeSets()
            .filter((item) => item.type == core_1.ChangeSetType.DELETE);
        deletionChangeSets.forEach((item) => {
            const metadata = Reflect.getMetadata(soft_deletable_symbol_1.SOFT_DELETABLE, item.entity.constructor);
            if (metadata) {
                const { field, value } = metadata;
                item.type = core_1.ChangeSetType.UPDATE;
                item.entity[field] = value();
                item.payload[field] = value();
                // Don't recompute here. Otherwise ManyToOne relation fields will be
                // set to `null` and cause a `NotNullConstraintViolationException`.
                // This only appear when using `cascade: [Cascade.ALL],
                // it will be fine to recompute here when using
                // `orphanRemoval: true`.
                // But because we can't catch the deletions caused by
                // `orphanRemoval`, we still chose `cascade: [Cascade.ALL],
                // uow.recomputeSingleChangeSet(item.entity);
            }
        });
    }
};
SoftDeletableHandlerSubscriber = tslib_1.__decorate([
    (0, core_1.Subscriber)()
], SoftDeletableHandlerSubscriber);
exports.SoftDeletableHandlerSubscriber = SoftDeletableHandlerSubscriber;
soft_deletable_decorator_1.SoftDeletable;
//# sourceMappingURL=soft-deletable-handler.subscriber.js.map