import "./soft-deletable-handler.subscriber";
/**
 * Mark an entity type as soft-deletable.
 * @see SoftDeletableHandlerSubscriber
 */
export declare function SoftDeletable<Entity, Field extends keyof Entity>(config: SoftDeletableConfig<Entity, Field>): EntityDecorator<Entity>;
/**
 * Mark an entity type as soft-deletable.
 * @param type - Helper function for type inference.
 * @param field - Identifier field used to identify deleted entities.
 * @param value - Value to set to the identifier field in deletions.
 * @param valueInitial - Value to identify entities that is NOT soft-deleted. Defaults to `null`.
 * @see SoftDeletableHandlerSubscriber
 */
export declare function SoftDeletable<Entity, Field extends keyof Entity>(type: () => Type<Entity>, field: Field, value: () => Entity[Field], valueInitial?: Entity[Field]): EntityDecorator<Entity>;
export interface SoftDeletableConfig<Entity, Field extends keyof Entity> {
    /**Helper function for type inference. */
    type: () => Type<Entity>;
    /**Identifier field used to identify deleted entities. */
    field: Field;
    /**Value to set to the identifier field in deletions. */
    value: () => Entity[Field];
    /**Value to identify entities that is NOT soft-deleted. Defaults to `null`. */
    valueInitial?: Entity[Field];
}
interface Type<T> {
    new (...args: any[]): T;
    prototype: T;
}
interface EntityDecorator<Entity> {
    (type: Type<Entity>): void;
}
export {};
//# sourceMappingURL=soft-deletable.decorator.d.ts.map